CREATE TABLE module_watchdog_services (
	name				VARCHAR(63) NOT NULL PRIMARY KEY
,	display_name		VARCHAR(63) NOT NULL
,	start_cmd			VARCHAR(255) NOT NULL
,	stop_cmd			VARCHAR(255) NOT NULL
,	mon_status			ENUM ('monitored', 'not monitored') NOT NULL DEFAULT 'not monitored'
,	poll_interval		SMALLINT UNSIGNED NOT NULL DEFAULT 60
,	connection_timeout	SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	restart				ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout				ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	restart_num			SMALLINT UNSIGNED NOT NULL DEFAULT 5
,	cycles_num			SMALLINT UNSIGNED NOT NULL DEFAULT 5

,	nonwork_alert		ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	nonwork_alert_to	VARCHAR(255)
,	nonwork_alert_from	VARCHAR(255)
,	nonwork_alert_subj	VARCHAR(255)

,	exec_alert			ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	exec_alert_to		VARCHAR(255)
,	exec_alert_from		VARCHAR(255)
,	exec_alert_subj		VARCHAR(255)

,	timeout_alert		ENUM ('on', 'off') NOT NULL DEFAULT 'on'
,	timeout_alert_to	VARCHAR(255)
,	timeout_alert_from	VARCHAR(255)
,	timeout_alert_subj	VARCHAR(255)
) TYPE=InnoDB;

CREATE TABLE module_watchdog_params (
	param				VARCHAR(255) NOT NULL PRIMARY KEY
,	val					VARCHAR(255)
) TYPE=InnoDB;


-- Inserting services.

INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('plesk_apache', 'Plesk web server', '/usr/local/psa/admin/bin/httpsdctl start', '/usr/local/psa/admin/bin/httpsdctl stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('apache', 'Web Server (Apache)', '/usr/local/psa/admin/bin/websrvmng --start', '/usr/local/psa/admin/bin/websrvmng --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('qmail', 'SMTP Server (QMail)', '/usr/local/psa/admin/bin/mailmng --start-smtpd', '/usr/local/psa/admin/bin/mailmng --stop-smtpd');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('courier-imap', 'IMAP/POP3 Server (Courier-IMAP)', '/usr/local/psa/admin/bin/mailmng --start-maild', '/usr/local/psa/admin/bin/mailmng --stop-maild');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('bind', 'DNS Server (BIND)', '/usr/local/psa/admin/bin/dnsmng --start', '/usr/local/psa/admin/bin/dnsmng --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('tomcat', 'Tomcat', '/usr/local/psa/admin/bin/tomcatmng --start', '/usr/local/psa/admin/bin/tomcatmng --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('coldfusion', 'ColdFusion', '/usr/local/psa/admin/bin/cfmng --start', '/usr/local/psa/admin/bin/cfmng --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('mysql', 'MySQL', '/etc/init.d/mysqld start', '/etc/init.d/mysqld stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('postgresql', 'PostgreSQL', '/usr/local/psa/admin/bin/pg_manage --start', '/usr/local/psa/admin/bin/pg_manage --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('psa-spamassassin', 'Plesk SpamAssassin', '/usr/local/psa/admin/bin/spamd --start', '/usr/local/psa/admin/bin/spamd --stop');
INSERT INTO module_watchdog_services (name, display_name, start_cmd, stop_cmd) VALUES ('drweb', 'Dr.Web antivirus', '/usr/local/psa/admin/bin/drwebmng --start', '/usr/local/psa/admin/bin/drwebmng --stop');

-- Inserting initial values of parameters.

INSERT INTO module_watchdog_params VALUES ('configured', 'false');
INSERT INTO module_watchdog_params VALUES ('monitrc.tpl', '/usr/local/psa/etc/modules/watchdog/monitrc.tpl');
INSERT INTO module_watchdog_params VALUES ('monitrc.chk', '/tmp/monitrc.chk');
INSERT INTO module_watchdog_params VALUES ('monitrc', '/usr/local/psa/etc/modules/watchdog/monitrc');
INSERT INTO module_watchdog_params VALUES ('monit.pid', '/usr/local/psa/var/modules/watchdog/run/monit.pid');

INSERT INTO module_watchdog_params VALUES ('automonit', 'on');
INSERT INTO module_watchdog_params VALUES ('poll interval', 300);
INSERT INTO module_watchdog_params VALUES ('monit TCP port', 2911);
INSERT INTO module_watchdog_params VALUES ('monit login', 'monit');
INSERT INTO module_watchdog_params VALUES ('monit password', CONCAT(LEFT( MD5(RAND()), 14), 'a'));
INSERT INTO module_watchdog_params VALUES ('mail servers', 'localhost');
INSERT INTO module_watchdog_params VALUES ('mail servers timeout', 5);
INSERT INTO module_watchdog_params SELECT 'default email to', val FROM misc WHERE param='admin_email' LIMIT 1;

INSERT INTO module_watchdog_params VALUES ('event::nonwork::to', '');
INSERT INTO module_watchdog_params VALUES ('event::nonwork::from', 'monitoring-service@<host>');
INSERT INTO module_watchdog_params VALUES ('event::nonwork::subj', '<service> on <host>: <event>.');
INSERT INTO module_watchdog_params VALUES ('event::nonwork::mess', '[<date>] <service> on <host>: <event>.');

INSERT INTO module_watchdog_params VALUES ('event::exec::to', '');
INSERT INTO module_watchdog_params VALUES ('event::exec::from', 'monitoring-service@<host>');
INSERT INTO module_watchdog_params VALUES ('event::exec::subj', '<service> on <host>: <event>.');
INSERT INTO module_watchdog_params VALUES ('event::exec::mess', '[<date>] <service> on <host>: <event>.');

INSERT INTO module_watchdog_params VALUES ('event::timeout::to', '');
INSERT INTO module_watchdog_params VALUES ('event::timeout::from', 'monitoring-service@<host>');
INSERT INTO module_watchdog_params VALUES ('event::timeout::subj', '<service> on <host> is nonresponsive and will no longer be monitored.');
INSERT INTO module_watchdog_params VALUES ('event::timeout::mess', '[<date>] <service> on <host> is no longer monitored due to permanent failure.');

INSERT INTO module_watchdog_params VALUES ('refresh services page', 'on');

-- Enable actions

INSERT IGNORE INTO actions(name, descr, enabled) VALUES ('service_stop', 'Stop Service', 'true');
INSERT IGNORE INTO actions(name, descr, enabled) VALUES ('service_start', 'Start Service', 'true');

-- Create event handlers

SELECT @start_action_id:=id FROM actions WHERE name='service_start' LIMIT 1;
SELECT @stop_action_id:=id FROM actions WHERE name='service_stop' LIMIT 1;

INSERT INTO event_handlers (action_id, user, command) VALUES (@start_action_id, 'psaadm', '/usr/local/psa/admin/bin/modules/watchdog/start-monit.php <new_service> --plesk-name');
INSERT INTO event_handlers (action_id, user, command) VALUES (@stop_action_id, 'psaadm', '/usr/local/psa/admin/bin/modules/watchdog/stop-monit.php <new_service> --plesk-name');

